Module prelude

Module prelude 

contains all the declarations such as structs, exports, enums, …

Re-exports

pub use crate::camera::Camera;
pub use crate::camera::CameraContainer;
pub use crate::camera::Projection;
pub use crate::engine::Engine;
pub use crate::engine::EngineSettings;
pub use crate::objects::Instance;
pub use crate::objects::InstanceRaw;
pub use crate::objects::Object;
pub use crate::objects::ObjectSettings;
pub use crate::objects::ObjectStorage;
pub use crate::objects::RotateAmount;
pub use crate::objects::RotateAxis;
pub use crate::render::Renderer;
pub use imports::*;

Modules

imports
re-exports from dependencies that are useful
macros
primitive_shapes
contains definition for some 2D and 3D shapes. They are basic shapes and can be used as examples of how to create your own content.

Structs

Pipeline
Container for pipeline values. Each pipeline takes only 1 vertex shader, 1 fragment shader, 1 texture data, and optionally a vector of uniform data.
ShaderSettings
These definitions are taken from wgpu API docs
SignalStorage
Handles the live events in the engine
Vertex
Will contain all details about a vertex and will be sent to GPU
VertexBuffers
Container for vertex and index buffer

Enums

PipelineData
Container for pipeline data. Allows for sharing resources with other objects
TextureData
Defines how the texture data is
TextureMode
Defines how the borders of texture would look like

Traits

Signal
Allows all events to be fetched directly, making it easier to add custom additions to the engine.

Functions

pixel_to_cartesian
This function helps in converting pixel value to the value that is between -1 and +1

Type Aliases

UnsignedIntType
The uint type used for indices and more
WindowSize
To hold the width and height of the engine frames