pub struct VertexBuffers {
pub vertex_buffer: Buffer,
pub index_buffer: Buffer,
pub length: u32,
}Expand description
Container for vertex and index buffer
Fields
vertex_buffer: BufferAn array of vertices. A vertex is a point in 3D space containing an X, Y, and a Z coordinate between -1 and +1
index_buffer: BufferAn array of indices. Indices are a way to reuse vertices, this in turn helps greatly in reduction of amount of vertices needed to be sent to the GPU
length: u32The length of the vertex buffer